---
title: Urubu 0.1 released
layout: page 
date: 2014-01-12
---

Introducing Urubu, a Python-based micro CMS for static websites.
Read about [the rationale behind it][rationale].

[rationale]: http://www.jandecaluwe.com/blog/i-dont-like-blogs.html
